# lncRNAs annotation workflow

This workflow uses the FEELnc tool to annotate long non-coding RNAs. Before annotating these long non-coding RNAs, StringTie will be used to assemble the RNA-seq alignments into potential trancriptions. The gffread tool provides a genome annotation file in GTF format.

For future analyses, it would be interesting to use an updated annotation containing messenger RNA and long non-coding RNA. The concatenante tool merges the reference annotation with the long non-coding RNA annotation obtained with FEELnc.

This workflow is taken from the tutorial “Long non-coding RNAs (lncRNAs) annotation with FEELnc” on the GTN.

## Workflows steps
- Transcript Assembly with StringTie: RNA-seq alignments are assembled into potential transcripts to provide a comprehensive view of expressed regions.
- Genome Annotation Conversion with GFFRead: Genome annotations are converted into a standardized format (GTF) to ensure compatibility with downstream tools.
- lncRNA Annotation with FEELnc: The FEELnc pipeline identifies and classifies long non-coding RNAs (lncRNAs) through three main steps:
    - Filter: Removes unwanted transcripts and those overlapping reference exons.
    - Codpot: Evaluates coding potential to differentiate lncRNAs from coding RNAs.
    - Classifier: Assigns lncRNAs to categories based on their genomic location and transcriptional direction.
- Annotation Merging with Concatenate: The lncRNA annotation is merged with the reference annotation to create a unified genome annotation containing both mRNAs and lncRNAs.

## Input data
The following input files are required for the workflow:
- RNA-seq alignments (BAM format): Required by StringTie for transcript assembly.
- Genome annotation (GFF3 format): Used by StringTie and GFFRead for processing.
- Genome sequence (FASTA format): Required by FEELnc for lncRNA identification.
- Reference annotation (GTF format): Provided by GFFRead for FEELnc analysis.

## Output data
The workflow produces the following outputs:
- Transcript annotation (GTF format): Generated by StringTie, containing assembled transcripts from RNA-seq data.
- Converted genome annotation (GTF format): Produced by GFFRead, used as input for FEELnc.
- lncRNA annotation (GTF format): Generated by FEELnc, containing identified lncRNAs.
- mRNA annotation (GTF format): Produced by FEELnc for downstream use.
- lncRNA classification table: Produced by FEELnc, detailing genomic relationships of lncRNAs.
- Comprehensive genome annotation (GTF format): Generated by Concatenate, combining mRNA and lncRNA annotations.
